CTTsub.RegOnTot: This function Computes subscores based on the observed total score in classical test theory (CTT)
Description
This function computes CTT subscores based on the observed total score,
using the method introduced in Haberman (2008), Haberman et al. (2009), and Sinharay (2010), which returns:
(1) Original Observed subscore;
(2) The true subscore is estimated based on the observed total score;
Usage
CTTsub.RegOnTot(test.data)
Arguments
test.data
A list that contains datasets of all subtests and the whole test,
which can be obtained using function 'data.prep'.
Value
A list of objects that include both test information and subscores.
(1) "subscore.information" - It contains test information of both subtests
and the total test, such as mean of subscores and total score, reliability, and PRMSE.
(2) "subscore.original" - It contains original subscores and total score.
(3) "subscore.RegOnTot" - It contains subscores that are estimated based on the observed total score.